# Xircuits Component Library List

## Internal Library

These components will always be included in the Xircuits installation.

<div align="center">

| Name     | Description                                                                                    | Link |
| -------- | ---------------------------------------------------------------------------------------------- | ---- |
| Controlflow | Components to enable ifs and loops. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_controlflow) |
| Template | Great components for new learners and to experiment outputs.                                   | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_template) |
| Utils    | Commonly used components for day-to-day workflows.                                             | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_utils) |


</div>


## External Library

Recognized additional component libraries that you can download and install using:

```bash
$ xircuits install <component library name>
```

<div align="center">

### 📊 Data Science, Machine Learning, and Data Processing
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Tensorflow Keras](https://github.com/XpressAI/xai-tensorflow-keras) | Harness the full potential of deep learning with TensorFlow Keras components. | - |
| [Pytorch](https://github.com/XpressAI/xai-pytorch) | Dive into deep learning with PyTorch's dynamic computation. | - |
| [SKlearn](https://github.com/XpressAI/xai-sklearn) | Empower your machine learning projects with Scikit-learn. | - |
| [XGBoost](https://github.com/XpressAI/xai-xgboost) | Boost your models' performance with XGBoost. | - |
| [Spark](https://github.com/XpressAI/xai-spark) | Scale your data processing and machine learning tasks with Spark. | - |
| [Pycaret](https://github.com/XpressAI/xai-pycaret) | Simplify your ML workflow with PyCaret. | 0.1.0 |

### 🤖 AI and Generative Models
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GPT Agent Toolkit](https://github.com/XpressAI/xai-gpt-agent-toolkit) | Experiment with CLM-based automatons. | 0.1.0 |
| [Vecto](https://github.com/XpressAI/xai-vecto) | Leverage vector embeddings in Xircuits. | 0.1.0 |
| [OpenAI](https://github.com/XpressAI/xai-openai) | Integrate OpenAI models and text generation. | 0.1.0 |
| [Anthropic](https://github.com/XpressAI/xai-anthropic) | Advanced anthropic principle components. | - |
| [HF Agent](https://github.com/XpressAI/xai-hfagent) | Components for Hugging Face agents. | - |
| [Actors](https://github.com/XpressAI/xai-actors) | Create actor models in Xircuits. | - |
| [VertexAI](https://github.com/XpressAI/xai-vertexai) | Interface with Google Vertex AI. | - |
| [Gemini](https://github.com/XpressAI/xai-google-gemini) | Google Generative AI integration. | - |
| [Converse](https://github.com/XpressAI/xai-converse) | Conversational AI with XpressAi API. | - |
| [Stability AI](https://github.com/XpressAI/xai-stability-ai) | Image generation and modification components. | - |

### 💬 Communication & Messaging
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Slack](https://github.com/XpressAI/xai-slack) | Interface with Slack. | 0.1.0 |
| [Discord](https://github.com/XpressAI/xai-discord) | Create Discord Bots. | 0.1.0 |
| [Telegram](https://github.com/XpressAI/xai-telegram) | Telegram bot integration. | - |
| [Twilio](https://github.com/XpressAI/xai-twilio) | SMS and voice communication. | - |
| [SendGrid](https://github.com/XpressAI/xai-sendgrid) | Email service integration. | - |

### 📡 Message Queues & Events
| Name | Description | Version |
| ---- | ----------- | ------- |
| [RabbitMQ](https://github.com/XpressAI/xai-rabbitmq) | Message broker integration. | 0.1.0 |
| [MQTT](https://github.com/XpressAI/xai-mqtt) | IoT Messaging standard implementation. | 0.1.0 |
| [Events](https://github.com/XpressAI/xai-events) | Event handling and processing. | - |

### 🗃 Databases & Web Services
| Name | Description | Version |
| ---- | ----------- | ------- |
| [SQLite](https://github.com/XpressAI/xai-sqlite) | SQLite database interface. | - |
| [Flask](https://github.com/XpressAI/xai-flask) | Flask web application development. | - |
| [MongoDB](https://github.com/XpressAI/xai-mongodb) | MongoDB database connection. | - |
| [Requests](https://github.com/XpressAI/xai-requests) | HTTP requests handling. | - |
| [SerpAPI](https://github.com/XpressAI/xai-serpapi) | Search engine results processing. | - |

### 🌍 Cloud & Productivity Services
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GDrive](https://github.com/XpressAI/xai-gdrive) | Google Drive integration. | - |
| [GSpread](https://github.com/XpressAI/xai-gspread) | Google Sheets interface. | - |
| [GCalendar](https://github.com/XpressAI/xai-gcalendar) | Google Calendar integration. | - |
| [GTasks](https://github.com/XpressAI/xai-gtasks) | Google Tasks management. | - |
| [AWS](https://github.com/XpressAI/xai-aws) | Amazon Web Services integration. | - |
| [GitHub](https://github.com/XpressAI/xai-github) | GitHub automation and integration. | - |
| [Confluence](https://github.com/XpressAI/xai-confluence) | Atlassian Confluence integration. | - |
| [Multion](https://github.com/XpressAI/xai-multion) | Multi-platform integration tools. | - |

### 🎨 UI & Visualization
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Streamlit](https://github.com/XpressAI/xai-streamlit) | Create interactive web apps. | 0.1.0 |
| [Gradio](https://github.com/XpressAI/xai-gradio) | Build ML demos effortlessly. | - |

</div>

Want your component library listed here? Just submit a PR to the Xircuits repository. For more information, refer to the [Xircuits component library documentation](https://xircuits.io/docs/component-library/).